@@ -289,7 +289,9 @@ OC.L10N.register(
     "Save" : "Konservi",
     "No results" : "Neniu rezulto",
     "Done" : "Farita",
+    "Grid view" : "Krada vido",
     "Copy link" : "Kopii ligilon",
+    "None" : "Nenio",
     "You" : "Vi",
     "Collapse" : "Maletendi",
     "Favorite" : "Pliŝatata",
@@ -312,9 +314,9 @@ OC.L10N.register(
     "Log in" : "Ensaluti",
     "Remove from favorites" : "Forigi el pliŝataĵoj",
     "Add to favorites" : "Aldoni al pliŝataĵoj",
+    "Home" : "Hejmo",
     "Users" : "Uzantoj",
     "Groups" : "Grupoj",
-    "None" : "Nenio",
     "Devices" : "Aparatoj",
     "Upload" : "Alŝuti",
     "Files" : "Dosieroj",
@@ -338,7 +340,8 @@ OC.L10N.register(
     "Performance" : "Rendimento",
     "Keyboard shortcuts" : "Fulmoklavoj",
     "Search" : "Serĉi",
-    "Grid view" : "Krada vido",
+    "More actions" : "Pliaj agoj",
+    "Default" : "Defaŭlta",
     "Keep" : "Konservi",
     "Select a region" : "Elekti regionon",
     "Submit" : "Sendi",
@@ -353,7 +356,6 @@ OC.L10N.register(
     "Other" : "Alia",
     "Group" : "Grupo",
     "Please reload the page." : "Bonvolu reŝargi la paĝon.",
-    "Default" : "Defaŭlta",
     "The password is wrong. Try again." : "La pasvorto malĝustas. Provu denove.",
     "Android app" : "Android-aplikaĵo",
     "iOS app" : "iOS-aplikaĵo",
