@@ -12,6 +12,7 @@ OC.L10N.register(
     "{actor} invited you to {call}" : "{actor} te ha invitado a {call}",
     "Talk" : "Hablar",
     "Guest" : "Invitado",
+    "Message deleted by author" : "Mensaje borrado por el autor",
     "Administration" : "Administración",
     "System" : "Sistema",
     "Talk to %s" : "Hablar con %s",
@@ -67,12 +68,14 @@ OC.L10N.register(
     "Attendees" : "Asistentes",
     "Save" : "Guardar",
     "No results" : "No hay resultados",
+    "Grid view" : "Vista de cuadrícula",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "¡Puedes invitar a otros usando la pestaña de participante de la barra lateral o compartiendo esta liga para invitar a otras personas!",
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
     "Copy link" : "Copiar liga",
     "Mute audio" : "Silenciar audio",
+    "None" : "Ninguno",
     "Disable video" : "Deshabilitar video",
     "Enable video" : "Habilitar el video",
     "You" : "Tú",
@@ -96,9 +99,9 @@ OC.L10N.register(
     "Log in" : "Ingresar",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a tus favoritos",
+    "Home" : "Inicio",
     "Users" : "Ususarios",
     "Groups" : "Grupos",
-    "None" : "Ninguno",
     "Devices" : "Dispositivos",
     "No audio" : "Sin audio",
     "Upload" : "Cargar",
@@ -127,6 +130,8 @@ OC.L10N.register(
     "Privacy" : "Privacidad",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Search" : "Buscar",
+    "More actions" : "Más acciones",
+    "Default" : "Predeterminado",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
@@ -136,7 +141,6 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
     "Show your screen" : "Mostrar tu pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
-    "Grid view" : "Vista de cuadrícula",
     "Submit" : "Enviar",
     "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
     "User" : "Usuario",
@@ -151,7 +155,6 @@ OC.L10N.register(
     "Group" : "Grupo",
     "Please reload the page." : "Por favor vuelve a cargar la página.",
     "Away" : "Ausente",
-    "Default" : "Predeterminado",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
     "Please move your setup to HTTPS" : "Por favor cambia tu configuración a HTTPS",
     "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
