@@ -82,6 +82,8 @@ OC.L10N.register(
     "Dismiss notification" : "התעלמות מהתראה",
     "Accept" : "אשר",
     "Decline" : "דחייה",
+    "New message" : "הודעה חדשה",
+    "Notification" : "הוֹדָעָה",
     "{user} sent you a private message" : "התקבלה הודעה פרטית מאת {user}",
     "{user} invited you to a group conversation: {call}" : "הוזמנת על ידי {user} לדיון קבוצתי: {call}",
     "Join call" : "הצטרפות לשיחה",
@@ -235,6 +237,7 @@ OC.L10N.register(
     "Saint Martin (French part)" : "סן מרטן (העבר הצרפתי)",
     "Madagascar" : "מדגסקר",
     "Marshall Islands" : "איי מרשל",
+    "North Macedonia" : "מקדוניה הצפונית",
     "Mali" : "מאלי",
     "Myanmar" : "מיאנמר",
     "Mongolia" : "מונגוליה",
@@ -400,7 +403,6 @@ OC.L10N.register(
     "Back" : "חזרה",
     "Cancel" : "ביטול",
     "Loading …" : "בטעינה…",
-    "No upcoming events" : "אין אירועים בזמן הקרוב",
     "From" : "מאת",
     "To" : "אל",
     "Calendar" : "לוח שנה",
@@ -409,12 +411,15 @@ OC.L10N.register(
     "Search participants" : "חיפוש משתתפים",
     "No results" : "אין תוצאות",
     "Done" : "הסתיים",
+    "Speaker view" : "תצוגת דובר",
+    "Grid view" : "תצוגת טבלה",
     "Waiting for others to join the call …" : "בהמתנה לאחרים להצטרף לשיחה…",
     "You can invite others in the participant tab of the sidebar" : "ניתן להזמין אחרים בלשונית המשתתפים בסרגל הצד",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "ניתן להזמין אחרים דרך לשונית המשתפים בסרגל הצד או לשתף את הקישור הזה כדי להזמין אחרים!",
     "Share this link to invite others!" : "יש לשתף את הקישור הזה כדי להזמין אחרים!",
     "Copy link" : "העתקת קישור",
     "Mute audio" : "השתקת שמע",
+    "None" : "אין",
     "Disable video" : "השבתת וידאו",
     "Enable video" : "הפעלת וידאו",
     "You" : "אני",
@@ -429,9 +434,9 @@ OC.L10N.register(
     "Disable" : "השבתה",
     "Choose" : "בחר",
     "Restricted" : "מוגבלת",
+    "Meeting" : "מפגש",
     "Conversation settings" : "הגדרות דיון",
     "Personal" : "אישי",
-    "Meeting" : "מפגש",
     "Leave conversation" : "יציאה מהדיון",
     "Delete conversation" : "מחיקת דיון",
     "_%n hour_::_%n hours_" : ["שעה","שעתיים","%n שעות"],
@@ -446,6 +451,8 @@ OC.L10N.register(
     "Bridge saved" : "הגישור נשמר",
     "Log content" : "תוכן הרישום",
     "Notifications" : "התראות",
+    "Important conversation" : "דיון חשוב",
+    "Join" : "הצטרף",
     "Error while creating the conversation" : "שגיאה ביצירת הדיון",
     "Create conversation" : "יצירת דיון",
     "Enter your name" : "נא למלא את שמך",
@@ -456,20 +463,22 @@ OC.L10N.register(
     "Add to favorites" : "הוספה למועדפים",
     "No matches found" : "לא נמצאו התאמות",
     "An error occurred while performing the search" : "אירעה שגיאה בעת ביצוע החיפוש",
+    "Unread messages" : "הודעות שלא נקראו",
     "Clear filter" : "מחיקת מסנן",
     "Users" : "משתמשים",
     "Groups" : "קבוצות",
     "Other sources" : "מקורות אחרים",
     "You are currently waiting in the lobby" : "הנך בהמתנה בלובי",
-    "None" : "אין",
+    "Test" : "בדיקה",
     "Devices" : "מכשירים",
     "No audio" : "אין שמע",
+    "Calls are not supported in your browser" : "אין תמיכה בשיחות בדפדפן שלך",
+    "Access to microphone was denied" : "הגישה למיקרופון נדחתה",
     "Invalid path selected" : "הנתיב שנבחר שגוי",
     "Upload" : "העלאה",
     "Files" : "קבצים",
     "Message sent" : "הודעה נשלחה",
     "Deleting message" : "ההודעה נמחקה",
-    "Unread messages" : "הודעות שלא נקראו",
     "Reply" : "תגובה",
     "Go to file" : "מעבר לקובץ",
     "Translate" : "תרגום",
@@ -483,8 +492,8 @@ OC.L10N.register(
     "Create a new group conversation" : "יצירת דיון קבוצתי חדש",
     "Add participants" : "הוספת משתתפים",
     "Send message" : "שליחת הודעה",
-    "Add emoji" : "הוספת אמוג׳י",
     "File to share" : "קובץ לשיתוף",
+    "Add emoji" : "הוספת אמוג׳י",
     "Share from Files" : "שיתוף מקבצים",
     "Share files to the conversation" : "שיתוף קבצים לדיון",
     "Create new poll" : "יצירת סקר חדש",
@@ -494,7 +503,6 @@ OC.L10N.register(
     "Create poll" : "יצירת סקר",
     "Settings" : "הגדרות",
     "Anonymous poll" : "סקר אלמוני",
-    "Join" : "הצטרף",
     "moderator" : "מפקח/ת",
     "guest" : "אורח",
     "Remove group and members" : "הסרת קבוצה וחברים",
@@ -515,18 +523,17 @@ OC.L10N.register(
     "Projects" : "מיזמים",
     "Link to a conversation" : "קישור לדיון",
     "Select conversation" : "בחירת דיון",
-    "Calls are not supported in your browser" : "אין תמיכה בשיחות בדפדפן שלך",
-    "Access to microphone was denied" : "הגישה למיקרופון נדחתה",
-    "Choose devices" : "בחירת התקנים",
-    "Attachments folder" : "תיקיית הקבצים המצורפים",
     "Select location for attachments" : "בחירת מיקום לקבצים מצורפים",
+    "Attachments folder" : "תיקיית הקבצים המצורפים",
     "Appearance" : "מראה",
     "Privacy" : "פרטיות",
     "Performance" : "ביצועים",
     "Keyboard shortcuts" : "קיצורי מקלדת",
     "Search" : "חיפוש",
     "Shortcuts while in a call" : "קיצורי דרך בזמן שיחה",
+    "More actions" : "פעולות נוספות",
     "Start call" : "התחלת שיחה",
+    "Default" : "בררת מחדל",
     "Screensharing options" : "אפשרויות שיתוף מסך",
     "Enable screensharing" : "הפעלת שיתוף מסך",
     "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
@@ -536,9 +543,8 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "אירעה שגיאה בעת התחלת שיתוף המסך.",
     "Show your screen" : "הצגת המסך שלך",
     "Stop screensharing" : "הפסקת שיתוף המסך",
-    "Speaker view" : "תצוגת דובר",
-    "Grid view" : "תצוגת טבלה",
     "Mute others" : "השתקה של אחרים",
+    "Keep" : "שימור",
     "Select a region" : "נא לבחור איזור",
     "Submit" : "שליחה",
     "Message without mention" : "הודעה ללא אזכור",
@@ -589,7 +595,6 @@ OC.L10N.register(
     "Please reload the page." : "יש להעלות מחדש דף זה.",
     "Do not disturb" : "לא להפריע",
     "Away" : "לא פה",
-    "Default" : "בררת מחדל",
     "Speaker {number}" : "רמקול {number}",
     "Access to microphone & camera is only possible with HTTPS" : "גישה למיקרופון ולמצלמה אפשרית רק עם HTTPS",
     "Please move your setup to HTTPS" : "נא להעביר את התצורה שלך ל־HTTPS",
@@ -606,6 +611,7 @@ OC.L10N.register(
     "Click the button below to join." : "יש ללחוץ על הכפתור שלהלן כדי להצטרף.",
     "{user} invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי {user}",
     "Copy conversation link" : "העתקת קישור דיון",
-    "Close" : "סגירה"
+    "Close" : "סגירה",
+    "Choose devices" : "בחירת התקנים"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
