@@ -499,6 +499,14 @@ OC.L10N.register(
     "Search participants" : "Caută participanți",
     "No results" : "Niciun rezultat",
     "Done" : "Realizat",
+    "Raise hand" : "Ridică mâna",
+    "Raise hand (R)" : "Ridică mâna (R)",
+    "Lower hand" : "Coboară mâna",
+    "Lower hand (R)" : "Coboară mâna (R)",
+    "Exit full screen (F)" : "Ieșire din ecran complet (F)",
+    "Full screen (F)" : "Ecran complet (F)",
+    "Speaker view" : "Vizualizare vorbitor",
+    "Grid view" : "Afișare în grilă",
     "This conversation is read-only" : "Această conversație este read-only",
     "{nickName} raised their hand." : "{nickName} a ridicat mâna.",
     "A participant raised their hand." : "Un participant a ridicat mâna.",
@@ -516,6 +524,7 @@ OC.L10N.register(
     "Mute audio (M)" : "Oprire sunet (M)",
     "Unmute audio" : "Reactivare sunet",
     "Unmute audio (M)" : "Reactivare sunet (M)",
+    "None" : "Niciuna",
     "Access to camera was denied" : "Accesul la cameră a fost respins",
     "Error while accessing camera: It is likely in use by another program" : "Eroare la accesul la cameră: Poate este folosită de alt program",
     "Error while accessing camera" : "Eroare la accesarea camerei",
@@ -549,12 +558,12 @@ OC.L10N.register(
     "Picture" : "Imagine",
     "Disable" : "Dezactivează",
     "Enable" : "Activare",
+    "Choose your conversation picture" : "Alegeți imaginea conversației",
     "Choose" : "Alege",
     "Upload conversation picture" : "Încarcă imaginea pentru conversație",
     "Choose conversation picture from files" : "Selectează imaginea conversației din Fișiere",
     "Remove conversation picture" : "Înlătură imaginea conversației",
     "Set picture" : "Setează imaginea",
-    "Choose your conversation picture" : "Alegeți imaginea conversației",
     "Default permissions modified for {conversationName}" : "Permisiunile implicite modificate pentru  {conversationName}",
     "Could not modify default permissions for {conversationName}" : "Nu au fost modificate permisiunile implicite pentru {conversationName}",
     "All permissions" : "Toate permisiunile",
@@ -565,7 +574,6 @@ OC.L10N.register(
     "Conversation settings" : "Configurația conversației",
     "Basic Info" : "Informații de bază",
     "Personal" : "Personal",
-    "Always show the device preview screen before joining a call in this conversation." : "Arată întotdeauna o previzualizare a ecranului dispozitvului înainte de a participa la această conversație.",
     "Moderation" : "Moderare",
     "Do you really want to delete \"{displayName}\"?" : "Sigur ștergeți \"{displayName}\"?",
     "Do you really want to delete all messages in \"{displayName}\"?" : "Sigur ștergeți toate mesajele din \"{displayName}\"?",
@@ -632,8 +640,10 @@ OC.L10N.register(
     "Users and groups" : "Utilizatori și grupuri",
     "Other sources" : "Alte surse",
     "The meeting will start soon" : "Întâlnirea va începe în curând",
-    "None" : "Niciuna",
     "Devices" : "Dispozitive",
+    "Calls are not supported in your browser" : "Apelurile video nu sunt suportate de browser",
+    "Access to microphone was denied" : "Accesul la microfon a fost respins",
+    "Error while accessing microphone" : "Eroare la accesarea microfonului",
     "Invalid path selected" : "Calea selectată este invalidă",
     "Blur" : "Blurează",
     "Upload" : "Încărcare",
@@ -667,8 +677,8 @@ OC.L10N.register(
     "Conversation visibility" : "Vizibilitatea conversației",
     "Enter password" : "Introduceți parola",
     "Joining conversation …" : "Alăturare la conversație ...",
-    "Cancel editing" : "Anulează editarea",
     "File to share" : "Fișier de partajat",
+    "Cancel editing" : "Anulează editarea",
     "Share from Files" : "Partajează din Fișiere",
     "Upload from device" : "Încarcă din dispozitiv",
     "New file" : "Fișier nou",
@@ -727,11 +737,10 @@ OC.L10N.register(
     "Select conversation" : "Selectare conversație",
     "Number length is not valid" : "Lungime număr incorectă",
     "Phone numbers" : "Numere de telefon",
+    "Display name: {name}" : "Numele afișat: {name}",
     "Save name" : "Salvează numele",
-    "Calls are not supported in your browser" : "Apelurile video nu sunt suportate de browser",
-    "Access to microphone was denied" : "Accesul la microfon a fost respins",
-    "Error while accessing microphone" : "Eroare la accesarea microfonului",
     "Choose the folder in which attachments should be saved." : "Selectați folderul în care se vor salva atașamentele",
+    "Select location for attachments" : "Selectați locația atașamentelor",
     "Error while setting attachment folder" : "Eroare la setarea dosarului pentru atașamente",
     "Your privacy setting has been saved" : "Setările de confidențialitate au fost salvate",
     "Error while setting read status privacy" : "Eroare la setarea confidențialității statusului de citire",
@@ -739,10 +748,8 @@ OC.L10N.register(
     "Failed to save sounds setting" : "Eroare la salvarea setărilor de sunet",
     "Sounds setting saved" : "Setările de sunet au fost salvate",
     "Error while saving sounds setting" : "Eroare la salvarea setărilor de sunet",
-    "Choose devices" : "Selectați dispozitivele",
     "Attachments folder" : "Dosarul pentru atașamente",
     "Browse …" : "Navigare ...",
-    "Select location for attachments" : "Selectați locația atașamentelor",
     "Appearance" : "Aspect",
     "Privacy" : "Confidențialitate",
     "Share my read-status and show the read-status of others" : "Arată statusul meu de citire și pe al celorlalți",
@@ -764,6 +771,7 @@ OC.L10N.register(
     "Space bar" : "Bara de spațiu",
     "Push to talk or push to mute" : "Apăsați pentru a vorbi sau pentru a suprima microfonul",
     "Raise or lower hand" : "Ridicare sau coborâre mână",
+    "More actions" : "Mai multe acțiuni",
     "Start call silently" : "Pornește videoconferința fără sunet",
     "Start call" : "Pornește videoconferința",
     "End call" : "Închidere videoconferință",
@@ -772,8 +780,7 @@ OC.L10N.register(
     "The call has been running for one hour." : "Videoconferința durează de o oră",
     "Send a reaction" : "Trimite o reacție",
     "React with {reaction}" : "Reacționează cu {reaction}",
-    "Disable background blur" : "Dezactivează blurarea fundalului",
-    "Blur background" : "Blurează fundalul",
+    "Default" : "Implicit",
     "You are not allowed to enable screensharing" : "Nu aveți permisiunea de partajare a ecranului",
     "No screensharing" : "Nicio partajare de ecran",
     "Screensharing options" : "Opțiuni pentru partajarea ecranului",
@@ -785,20 +792,13 @@ OC.L10N.register(
     "Bad sent audio and screen quality." : "Calitate proastă audio și imagine.",
     "Bad sent audio and video quality." : "Calitate proastă audio și video.",
     "Bad sent audio quality." : "Calitate audio proastă.",
+    "Disable background blur" : "Dezactivează blurarea fundalului",
     "Disable screenshare" : "Dezactivează partajarea ecranului",
     "Screen sharing is not supported by your browser." : "Partajarea ecranului nu e posibilă în acest browser.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Folosiți un alt browser precum Firefox și Chrome pentru partajarea ecranului.",
     "An error occurred while starting screensharing." : "Eroare la partajarea ecranului.",
     "Show your screen" : "Prezentați ecranul",
     "Stop screensharing" : "Oprește partajarea ecranului",
-    "Exit full screen (F)" : "Ieșire din ecran complet (F)",
-    "Full screen (F)" : "Ecran complet (F)",
-    "Speaker view" : "Vizualizare vorbitor",
-    "Grid view" : "Afișare în grilă",
-    "Raise hand" : "Ridică mâna",
-    "Raise hand (R)" : "Ridică mâna (R)",
-    "Lower hand" : "Coboară mâna",
-    "Lower hand (R)" : "Coboară mâna (R)",
     "Mute others" : "Închide microfonul celorlalți",
     "Toggle full screen" : "Comută în ecran complet",
     "Remove participant {name}" : "Elimină participantul {name}",
@@ -812,7 +812,6 @@ OC.L10N.register(
     "Join a conversation or start a new one!" : "Particiăați la o conversație sau creați una nouă!",
     "Duplicate session" : "Sesiune duplicat",
     "Join a conversation or start a new one" : "Participați la o conversație sau începeți una nouă",
-    "Display name: {name}" : "Numele afișat: {name}",
     "Talk conversation" : "Conversație Talk",
     "User" : "Utilizator",
     "Password" : "Parolă",
@@ -848,6 +847,11 @@ OC.L10N.register(
     "Leave this page" : "Părăsește pagina",
     "Join here" : "Alăturare aici",
     "Deck card has been posted to {conversation}" : "Cardul Deck a fost postat la conversația {conversation}",
+    "An error occurred while posting deck card to conversation" : "Eroare la postarea cardului Deck în conversație",
+    "Post to a conversation" : "Postare într-o conversație",
+    "Post to conversation" : "Postare în conversație",
+    "Share to a conversation" : "Partajare la o conversație",
+    "Share to conversation" : "Partajare la conversație",
     "Error while clearing conversation history" : "Eroare la ștergerea istoricului conversației",
     "Conversation password has been saved" : "Parola conversației a fost salvată",
     "Conversation password has been removed" : "Parola conversație a fost ștearsă",
@@ -872,7 +876,6 @@ OC.L10N.register(
     "Please reload the page." : "Te rugăm să reîncarci pagina.",
     "Do not disturb" : "Nu deranja",
     "Away" : "Plecat",
-    "Default" : "Implicit",
     "Microphone {number}" : "Microfon {number}",
     "Speaker {number}" : "Vorbitor {number}",
     "Access to microphone & camera was denied" : "Accesul la microfon și cameră a fost refuzat",
@@ -888,10 +891,13 @@ OC.L10N.register(
     "Click the button below to join." : "Apăsați butonul pentru a vă alătura.",
     "Join »%s«" : "Alăturați-vă »%s«",
     "{user} invited you to a private conversation" : "{user} v-a invitat într-o conversație privată",
+    "Always show the device preview screen before joining a call in this conversation." : "Arată întotdeauna o previzualizare a ecranului dispozitvului înainte de a participa la această conversație.",
     "Copy conversation link" : "Copiază linkul conversației",
     "Filter unread mentions" : "Filtrează mențiunile necitite",
     "Filter unread messages" : "Filtrează mesajele necitite",
     "Close" : "Închide",
+    "Choose devices" : "Selectați dispozitivele",
+    "Blur background" : "Blurează fundalul",
     "An error happened when trying to share your file" : "Eroare la încercarea de partajare a fișierului",
     "Failed to join the conversation. Try to reload the page." : "Eroare la încercarea de participare la conversație. Încercați să reîncărcați pagina. "
 },
