@@ -352,6 +352,10 @@ OC.L10N.register(
     "Search participants" : "Tìm kiếm người tham gia",
     "No results" : "Không có kết quả",
     "Done" : "Hoàn thành",
+    "Raise hand" : "Giơ tay",
+    "Lower hand" : "Đặt tay xuống",
+    "Speaker view" : "Chế độ xem người gọi điện",
+    "Grid view" : "Xem dạng Lưới",
     "This conversation is read-only" : "Cuộc trò chuyện này ở chế độ chỉ đọc",
     "{nickName} raised their hand." : "{nickName} giơ tay.",
     "A participant raised their hand." : "Một người tham gia giơ tay.",
@@ -367,6 +371,7 @@ OC.L10N.register(
     "Copy link" : "Sao chép liên kết",
     "Mute audio" : "Tắt âm thanh",
     "Unmute audio" : "Bật âm thanh",
+    "None" : "Không có",
     "Access to camera was denied" : "Quyền truy cập vào máy ảnh đã bị từ chối",
     "Error while accessing camera" : "Lỗi khi truy cập máy ảnh",
     "You have been muted by a moderator" : "Bạn đã bị người kiểm duyệt tắt tiếng",
@@ -447,6 +452,7 @@ OC.L10N.register(
     "Add to favorites" : "Thêm vào ưa thích",
     "You need to promote a new moderator before you can leave the conversation." : "Bạn cần chọn người kiểm duyệt mới trước khi có thể rời khỏi cuộc trò chuyện.",
     "Conversation actions" : "Hoạt động cuộc trò chuyện",
+    "Home" : "Trang nhà",
     "No conversations found" : "Không tìm thấy cuộc trò chuyện nào",
     "An error occurred while performing the search" : "Đã xảy ra lỗi khi thực hiện tìm kiếm",
     "Conversation list" : "Danh sách cuộc trò chuyện",
@@ -460,13 +466,17 @@ OC.L10N.register(
     "Users and groups" : "Người dùng và nhóm",
     "Other sources" : "Những nguồn khác",
     "You are currently waiting in the lobby" : "Bạn hiện đang đợi ở sảnh đợi",
-    "None" : "Không có",
     "Select microphone" : "Chọn micrô",
     "No microphone available" : "Không có micrô",
     "Select camera" : "Chọn camera",
     "No camera available" : "Không có camera khả dụng",
     "No audio" : "Không có âm thanh",
     "No camera" : "Không có máy ảnh",
+    "Calls are not supported in your browser" : "Cuộc gọi không được hỗ trợ trong trình duyệt của bạn",
+    "Access to microphone is only possible with HTTPS" : "Chỉ có thể truy cập vào micrô với HTTPS",
+    "Access to microphone was denied" : "Quyền truy cập vào micrô đã bị từ chối",
+    "Error while accessing microphone" : "Lỗi khi truy cập micrô",
+    "Access to camera is only possible with HTTPS" : "Chỉ có thể truy cập vào camera với HTTPS",
     "Invalid path selected" : "Đường dẫn đã chọn không hợp lệ",
     "Upload" : "Tải lên",
     "Files" : "Tệp",
@@ -505,8 +515,8 @@ OC.L10N.register(
     "No permission to post messages in this conversation" : "Không có quyền đăng tin nhắn trong cuộc trò chuyện này",
     "Joining conversation …" : "Tham gia cuộc trò chuyện …",
     "Send message" : "Gửi thông điệp",
-    "Add emoji" : "Thêm biểu tượng cảm xúc",
     "File to share" : "Tệp để chia sẻ",
+    "Add emoji" : "Thêm biểu tượng cảm xúc",
     "Share from Files" : "Chia sẻ từ Thư mục",
     "Share files to the conversation" : "Chia sẻ tệp với cuộc trò chuyện",
     "New file" : "Tập tin mới",
@@ -549,18 +559,12 @@ OC.L10N.register(
     "Search conversations or users" : "Tìm kiếm cuộc trò chuyện hoặc người dùng",
     "Select conversation" : "Chọn cuộc trò chuyện",
     "Edit display name" : "Chỉnh sửa tên hiển thị",
-    "Calls are not supported in your browser" : "Cuộc gọi không được hỗ trợ trong trình duyệt của bạn",
-    "Access to microphone is only possible with HTTPS" : "Chỉ có thể truy cập vào micrô với HTTPS",
-    "Access to microphone was denied" : "Quyền truy cập vào micrô đã bị từ chối",
-    "Error while accessing microphone" : "Lỗi khi truy cập micrô",
-    "Access to camera is only possible with HTTPS" : "Chỉ có thể truy cập vào camera với HTTPS",
+    "Select location for attachments" : "Chọn vị trí cho tệp đính kèm",
     "Error while setting attachment folder" : "Lỗi khi cấu hình thư mục tệp đính kèm",
     "Your privacy setting has been saved" : "Các thiết lập quyền riêng tư của bạn đã được lưu",
     "Error while setting read status privacy" : "Lỗi khi đặt quyền riêng tư của trạng thái đã đọc",
     "Failed to save sounds setting" : "Không thể lưu cài đặt âm thanh",
-    "Choose devices" : "Chọn thiết bị",
     "Attachments folder" : "Thư mục đính kèm",
-    "Select location for attachments" : "Chọn vị trí cho tệp đính kèm",
     "Appearance" : "Ngoại hình",
     "Privacy" : "Bảo mật",
     "Share my read-status and show the read-status of others" : "Chia sẻ trạng thái đã đọc của tôi và hiển thị trạng thái đã đọc của những người khác",
@@ -576,8 +580,10 @@ OC.L10N.register(
     "Space bar" : "Thanh dấu cách",
     "Push to talk or push to mute" : "Nhấn để nói hoặc tắt tiếng",
     "Raise or lower hand" : "Giơ tay hoặc hạ tay",
+    "More actions" : "Nhiều hành động hơn",
     "Start call" : "Bắt đầu cuộc gọi",
     "You will be able to join the call only after a moderator starts it." : "Bạn sẽ chỉ có thể tham gia cuộc gọi sau khi người kiểm duyệt bắt đầu cuộc gọi.",
+    "Default" : "Mặc định",
     "Screensharing options" : "Tùy chọn chia sẻ màn hình",
     "Enable screensharing" : "Bật chia sẽ màn hình",
     "Bad sent video and screen quality." : "Chất lượng màn hình và video đã gửi kém.",
@@ -602,10 +608,6 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Đã xảy ra lỗi khi bắt đầu chia sẻ màn hình.",
     "Show your screen" : "Hiện màn hình của bạn",
     "Stop screensharing" : "Ngừng chia sẽ màn hình",
-    "Speaker view" : "Chế độ xem người gọi điện",
-    "Grid view" : "Xem dạng Lưới",
-    "Raise hand" : "Giơ tay",
-    "Lower hand" : "Đặt tay xuống",
     "Mute others" : "Tắt tiếng người khác",
     "Keep" : "Giữ",
     "Select a region" : "Chọn một khu vực",
@@ -668,6 +670,8 @@ OC.L10N.register(
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Bạn đang cố gắng tham gia một cuộc trò chuyện trong khi có một phiên hoạt động trong một cửa sổ hoặc thiết bị khác. Điều này hiện không được vWorkspace Talk hỗ trợ. Bạn muốn làm gì?",
     "Leave this page" : "Rời khỏi trang này",
     "Join here" : "Tham gia tại đây",
+    "Post to a conversation" : "Đăng lên một cuộc trò chuyện",
+    "Post to conversation" : "Đăng lên cuộc trò chuyện",
     "Error occurred while allowing guests" : "Đã xảy ra lỗi khi cho phép khách",
     "Error occurred while disallowing guests" : "Đã xảy ra lỗi khi không cho phép khách",
     "Error occurred when restricting the conversation to moderator" : "Đã xảy ra lỗi khi giới hạn cuộc trò chuyện với người kiểm duyệt",
@@ -691,7 +695,6 @@ OC.L10N.register(
     "Please reload the page." : "Vui lòng tải lại trang.",
     "Do not disturb" : "Đừng làm phiền",
     "Away" : "Tạm vắng",
-    "Default" : "Mặc định",
     "Microphone {number}" : "Micrô {number}",
     "Camera {number}" : "Máy ảnh {number}",
     "Speaker {number}" : "Người nói {number}",
@@ -720,6 +723,7 @@ OC.L10N.register(
     "{user} invited you to a private conversation" : "{user} đã mời bạn tham gia cuộc trò chuyện riêng",
     "Copy conversation link" : "Sao chép liên kết cuộc trò chuyện",
     "Close" : "Đóng",
+    "Choose devices" : "Chọn thiết bị",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "vWorkspace Talk đã được cập nhật, bạn cần tải lại trang trước khi có thể bắt đầu hoặc tham gia cuộc gọi.",
     "Nextcloud Talk was updated, please reload the page" : "vWorkspace Talk đã được cập nhật, vui lòng tải lại trang",
     "Failed to join the conversation. Try to reload the page." : "Không tham gia được cuộc trò chuyện. Hãy thử tải lại trang.",
