@@ -40,10 +40,23 @@ class Room {
 	public const TYPE_NOTE_TO_SELF = 6;
 
 	public const OBJECT_TYPE_EMAIL = 'emails';
+	public const OBJECT_TYPE_EVENT = 'event';
+	public const OBJECT_TYPE_EXTENDED_CONVERSATION = 'extended_conversation';
 	public const OBJECT_TYPE_FILE = 'file';
-	public const OBJECT_TYPE_PHONE = 'phone';
+	public const OBJECT_TYPE_INSTANT_MEETING = 'instant_meeting';
+	public const OBJECT_TYPE_NOTE_TO_SELF = 'note_to_self';
+	/**
+	 * @deprecated No longer used for new conversations
+	 */
+	public const OBJECT_TYPE_PHONE_LEGACY = 'phone';
+	public const OBJECT_TYPE_PHONE_PERSIST = 'phone_persist';
+	public const OBJECT_TYPE_PHONE_TEMPORARY = 'phone_temporary';
+	public const OBJECT_TYPE_SAMPLE = 'sample';
 	public const OBJECT_TYPE_VIDEO_VERIFICATION = 'share:password';
 
+	public const OBJECT_ID_PHONE_OUTGOING = 'phone';
+	public const OBJECT_ID_PHONE_INCOMING = 'direct-dialin';
+
 	public const RECORDING_NONE = 0;
 	public const RECORDING_VIDEO = 1;
 	public const RECORDING_AUDIO = 2;
@@ -75,7 +88,7 @@ class Room {
 	public const START_CALL_MODERATORS = 2;
 	public const START_CALL_NOONE = 3;
 
-	public const DESCRIPTION_MAXIMUM_LENGTH = 500;
+	public const DESCRIPTION_MAXIMUM_LENGTH = 2000;
 
 	public const HAS_FEDERATION_NONE = 0;
 	public const HAS_FEDERATION_TALKv1 = 1;
@@ -573,4 +586,12 @@ class Room {
 	public function setMentionPermissions(int $mentionPermissions): void {
 		$this->mentionPermissions = $mentionPermissions;
 	}
+
+	public function setObjectId(string $objectId): void {
+		$this->objectId = $objectId;
+	}
+
+	public function setObjectType(string $objectType): void {
+		$this->objectType = $objectType;
+	}
 }
