@@ -15,7 +15,7 @@ final class TransformerHasInvalidCallableParameter extends LogicException
     public function __construct(MethodDefinition|FunctionDefinition $method, Type $parameterType)
     {
         parent::__construct(
-            "Transformer's second parameter must be a callable, `{$parameterType->toString()}` given for `{$method->signature()}`.",
+            "Transformer's second parameter must be a callable, `{$parameterType->toString()}` given for `$method->signature`.",
             1695065710,
         );
     }
