@@ -19,18 +19,34 @@ use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Token\IntegerValueToken;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Token\IntersectionToken;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Token\IterableToken;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Token\ListToken;
-use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Token\NativeToken;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Token\NullableToken;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Token\ValueOfToken;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Token\OpeningBracketToken;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Token\OpeningCurlyBracketToken;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Token\OpeningSquareBracketToken;
-use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Token\QuoteToken;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Token\StringValueToken;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Token\Token;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Token\TripleDotsToken;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Token\TypeToken;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Parser\Lexer\Token\UnionToken;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\ArrayKeyType;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\BooleanValueType;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\MixedType;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\NativeBooleanType;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\NativeFloatType;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\NativeStringType;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\NegativeIntegerType;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\NonEmptyStringType;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\NonNegativeIntegerType;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\NonPositiveIntegerType;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\NullType;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\NumericStringType;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\PositiveIntegerType;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\UndefinedObjectType;
 
 use function filter_var;
 use function is_numeric;
+use function str_starts_with;
 use function strtolower;
 
 /** @internal */
@@ -40,11 +56,7 @@ final class NativeLexer implements TypeLexer
 
     public function tokenize(string $symbol): Token
     {
-        if (NativeToken::accepts($symbol)) {
-            return NativeToken::from($symbol);
-        }
-
-        $token = match (strtolower($symbol)) {
+        return match (strtolower($symbol)) {
             '|' => UnionToken::get(),
             '&' => IntersectionToken::get(),
             '<' => OpeningBracketToken::get(),
@@ -58,7 +70,7 @@ final class NativeLexer implements TypeLexer
             '?' => NullableToken::get(),
             ',' => CommaToken::get(),
             '...' => TripleDotsToken::get(),
-            '"', "'" => new QuoteToken($symbol),
+
             'int', 'integer' => IntegerToken::get(),
             'array' => ArrayToken::array(),
             'non-empty-array' => ArrayToken::nonEmptyArray(),
@@ -67,21 +79,30 @@ final class NativeLexer implements TypeLexer
             'iterable' => IterableToken::get(),
             'class-string' => ClassStringToken::get(),
             'callable' => CallableToken::get(),
-            default => null,
+            'value-of' => ValueOfToken::get(),
+
+            'null' => new TypeToken(NullType::get()),
+            'true' => new TypeToken(BooleanValueType::true()),
+            'false' => new TypeToken(BooleanValueType::false()),
+            'mixed' => new TypeToken(MixedType::get()),
+            'float' => new TypeToken(NativeFloatType::get()),
+            'positive-int' => new TypeToken(PositiveIntegerType::get()),
+            'negative-int' => new TypeToken(NegativeIntegerType::get()),
+            'non-positive-int' => new TypeToken(NonPositiveIntegerType::get()),
+            'non-negative-int' => new TypeToken(NonNegativeIntegerType::get()),
+            'string' => new TypeToken(NativeStringType::get()),
+            'non-empty-string' => new TypeToken(NonEmptyStringType::get()),
+            'numeric-string' => new TypeToken(NumericStringType::get()),
+            'bool', 'boolean' => new TypeToken(NativeBooleanType::get()),
+            'array-key' => new TypeToken(ArrayKeyType::default()),
+            'object' => new TypeToken(UndefinedObjectType::get()),
+
+            default => match (true) {
+                str_starts_with($symbol, "'") || str_starts_with($symbol, '"') => new StringValueToken($symbol),
+                filter_var($symbol, FILTER_VALIDATE_INT) !== false => new IntegerValueToken((int)$symbol),
+                is_numeric($symbol) => new FloatValueToken((float)$symbol),
+                default => $this->delegate->tokenize($symbol),
+            },
         };
-
-        if ($token) {
-            return $token;
-        }
-
-        if (filter_var($symbol, FILTER_VALIDATE_INT) !== false) {
-            return new IntegerValueToken((int)$symbol);
-        }
-
-        if (is_numeric($symbol)) {
-            return new FloatValueToken((float)$symbol);
-        }
-
-        return $this->delegate->tokenize($symbol);
     }
 }
